Skip to contents

The ids of every sink currently registered, in the order they fire. The console sink is always first under the reserved id "console" unless it has been removed.

Usage

logtree_sinks()

Value

A character vector of sink ids.

Examples

logtree_sinks()
#> [1] "console" "sink3"   "sink4"   "sink5"   "sink6"