R/sinks.R
logtree_sinks.Rd
The ids of every sink currently registered, in the order they fire. The console sink is always first under the reserved id "console" unless it has been removed.
"console"
logtree_sinks()
A character vector of sink ids.
logtree_sink(), logtree_sink_remove()
logtree_sink()
logtree_sink_remove()
logtree_sinks() #> [1] "console" "sink3" "sink4" "sink5" "sink6"